==> tsipp3.1a.tar.gz: tsipp3.1a/libsipp/smalloc.c <==
/**
 ** sipp - SImple Polygon Processor
 **
 **  A general 3d graphic package
 **
 **  Copyright Equivalent Software HB  1992
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 1, or any later version.
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 ** You can receive a copy of the GNU General Public License from the
 ** Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/

/**
 ** smalloc.c - "Safe" malloc and calloc.
 **/

#ifdef HAVE_MALLOC_H
#    include <malloc.h>
#endif
#include <stdio.h>


void *
smalloc(size)
    int size;
{
    char *p;

    p = malloc(size);
    if (p == NULL) {
        fprintf(stderr, "smalloc(): Out of memory.\n");
        exit(1);
    }

    return p;
}


void *
scalloc(size, itemsize)
    int size;
    int itemsize;
{
    char *p;

    p = (char *)calloc(size, itemsize);
    if (p == NULL) {
        fprintf(stderr, "scalloc(): Out of memory.\n");
        exit(1);
    }

    return p;
}


void *
srealloc(ptr, size)
    void *ptr;
    int   size;
{
    char *p;
 
    p = realloc(ptr, size);
    if (p == NULL) {
        fprintf(stderr, "srealloc(): Out of memory.\n");
        exit(1);
    }

    return p;
}

==> tsipp3.2.0-b1.tar.gz: tsipp3.2.0-b1/libsipp/smalloc.c <==
/**
 ** sipp - SImple Polygon Processor
 **
 **  A general 3d graphic package
 **
 **  Copyright Equivalent Software HB  1992
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation; either version 1, or any later version.
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 ** You can receive a copy of the GNU General Public License from the
 ** Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 **/

/**
 ** smalloc.c - "Safe" malloc and calloc.
 **/

#ifdef STDC_HEADERS
#    include <stdlib.h>
#endif
#if defined(HAVE_MALLOC_H) && !defined(STDC_HEADERS)
#   include <malloc.h>
#endif
#include <stdio.h>


void *
smalloc(size)
    int size;
{
    char *p;

    p = malloc(size);
    if (p == NULL) {
        fprintf(stderr, "smalloc(): Out of memory.\n");
        exit(1);
    }

    return p;
}


void *
scalloc(size, itemsize)
    int size;
    int itemsize;
{
    char *p;

    p = (char *)calloc(size, itemsize);
    if (p == NULL) {
        fprintf(stderr, "scalloc(): Out of memory.\n");
        exit(1);
    }

    return p;
}


void *
srealloc(ptr, size)
    void *ptr;
    int   size;
{
    char *p;
 
    p = realloc(ptr, size);
    if (p == NULL) {
        fprintf(stderr, "srealloc(): Out of memory.\n");
        exit(1);
    }

    return p;
}
